thorn.utils.hmac — Thorn 1.3.0 documentation

# thorn.utils.hmac

- thorn.utils.hmac

## thorn.utils.hmac

HMAC Message signing utilities.

`thorn.utils.hmac.` `compat_sign`(digest_method, key, message)

`thorn.utils.hmac.` `get_digest`(d)

`thorn.utils.hmac.` `random_secret`(length, chars=u'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!#$%&()*+, -./:;<=>?@[\\]^_`{|}~')

`thorn.utils.hmac.` `sign`(digest_method, key, message)

`thorn.utils.hmac.` `verify`(digest, digest_method, key, message)